=======================
Installation
=======================

camrcs
=======================

Via github
-----------

.. code-block:: console
   
   $ cd path/to/clone
   $ git clone https://github.com/niekwit/camrcs.git
   $ cd camrcs
   $ pip install .


This will install the latest development version of `camrcs`.


Via PyPi
----------

.. code-block:: console
   
   $ pip install camrcs


This will install the most recent stable version of `camrcs`.


pigz
=======================

``camrcs`` uses ``pigz`` for data compression

Debian-based GNU/Linux
-----------------------

.. code-block:: console
   
   $ sudo apt-get install pigz


Fedora and RHEL GNU/Linux
---------------------------

.. code-block:: console
   
   $ sudo dnf install pigz


Arch-based GNU/Linux
----------------------

.. code-block:: console
   
   $ sudo pacman -S pigz


SuSE and openSuSE GNU/Linux 
----------------------------

.. code-block:: console
   
   $ sudo zypper install pigz


MacOS
--------

.. code-block:: console
   
   $ brew install pigz







